@@ -21,7 +21,6 @@
 #' @param add_column string, a column name in d_to to add to the output. Defaults to \emph{NULL}.
 #' @param keep_data boolean, whether to include empty rows with only the \emph{d_from_ID} column filed out for cases that have data in the \emph{d_from}, but not within the time range. Defaults to \emph{FALSE}.
 #' @param nThread integer, number of threads to use by \emph{dopar} for parallelization. If it is set to 1, then no parallel backends are created and the function is executed sequentially.
-#' On windows machines sockets are used, while on other operating systems fork parallelization is used.
 #'
 #' @return data table, with \emph{d_from} filtered to ones only within the timeframe. The columns of \emph{d_from} are returned with the corresponding time column in \emph{data_to}
 #' where the rows are instances which comply with the time constraints specified by the function. An additional column specified in \emph{time_diff_name} is also returned,
@@ -40,13 +39,9 @@ find_exam_bm <- function(d_from, d_to,
   .SD=.N=.I=.GRP=.BY=.EACHI=..=..cols=.SDcols=i=j=time_to_db=..which_ids_to=..which_ids_from=..collapse <- NULL
 
   #Initialize multicore
-  if(nThread == 1) {
-    `%exec%` <- foreach::`%do%`
-  } else {
-    cl <- parallel::makeCluster(nThread, type = "PSOCK", methods = FALSE, useXDR = FALSE)
-    doParallel::registerDoParallel(cl)
-    `%exec%` <- foreach::`%dopar%`
-  }
+  cl <- parallel::makeCluster(nThread, methods = FALSE, useXDR = FALSE)
+  doParallel::registerDoParallel(cl)
+  `%exec%` <- foreach::`%dopar%`
 
   #Convert to bigmemory compatible format
   d_from <- data.table::copy(d_from)
@@ -83,7 +78,7 @@ find_exam_bm <- function(d_from, d_to,
   out <- empty; i = 1
 
   #Create iterator
-  if(nThread == 1 | dim(d_to)[1]<100) {
+  if(dim(d_to)[1]<100) {
     blocks <- list(1:dim(d_to)[1])
   } else {
     groups <- cut(1:dim(d_to)[1], breaks = nThread, labels = 1:nThread)
@@ -92,7 +87,6 @@ find_exam_bm <- function(d_from, d_to,
   }
 
 
-
   #Create bigmemory matrices
   d_from <- suppressWarnings(bigmemory::as.big.matrix(x = d_from, type = "double", shared = TRUE, separated = FALSE))
   d_to   <- suppressWarnings(bigmemory::as.big.matrix(x = d_to, type = "double", shared = TRUE, separated = FALSE))
@@ -227,7 +221,7 @@ find_exam_bm <- function(d_from, d_to,
 
   if(!is.null(add_column)) {
     result_conv_add <- lapply(add_column, function(x) {
-      if(all(is.na(result[[x]]))) {
+      if(length(is.na(result[[x]]))==0 | all(is.na(result[[x]]))) {
         out <- as.character(result[[x]])
       } else {
         out <- factor(result[[x]],
